<?php
/* $Id: turkish-utf-8.inc.php,v 2.80.2.1 2005/09/02 19:55:48 lem9 Exp $ */

// son güncelleme:28.08.2005 (in nova roma)
// Türkçe Çeviri ® Bora Alioğlu
// mail: boralioglu[at]gmail.{com}
// icq uin: 20940178
// #######################################################
// çeviri hakkındaki her türlü düzeltme ve önerileriniz
// için benimle temasa geçebilirsiniz...
// #######################################################
// son güncelleme:28.08.2005 (in nova roma)
//
//                                       "o temporas o mores"

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';

$byteUnits = array('Byte', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
$day_of_week = array('Pazar', 'Pazartesi', 'Salı', 'Çarşamba', 'Perşembe', 'Cuma', 'Cumartesi');
$month = array('Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık');

// Aşağıdaki değişkenin tanımlanması hakkında daha fazla bilgi için
// http://www.php.net/manual/en/function.strftime.php sitesine gözatınız

$datefmt = '%B %d, %Y at %I:%M %p';

$timespanfmt = '%s gün, %s saat, %s dakika ve %s saniye';

//new translations begin here

 

 

 

 

 

 

 

$strAbortedClients = 'İptal edildi';
$strAbsolutePathToDocSqlDir = 'Lütfen web sunucusu üzerinde docSQL dizinine giden tam yolu giriniz  ';
$strAccessDenied = 'Erişim engellendi';
$strAccessDeniedExplanation = 'phpMyAdmin MySQL sunucusuna bağlanmayı denedi  sunucu bağlantıyı reddetti. config.inc içerisindeki bilgisayar adresini(host) , kullanıcı adını ve şifreyi kontrol edin ve MySQL sunucusunun yöneticisi tarafından size verilen bilgiyle uyuştuğundan emin olun.';
$strAction = 'Eylem';
$strAddAutoIncrement = 'Otomatik artma ekle';
$strAddConstraints = 'Sınırlama ekle';
$strAddDeleteColumn = 'Sütun alanı Ekle/Sil';
$strAddDeleteRow = 'Kriter satırı Ekle/Sil';
$strAddDropDatabase = '<b>DROP DATABASE</b> ekle';
$strAddedColumnComment = 'Sütun için eklenmiş yorum';
$strAddedColumnRelation = 'Sütun için eklenmiş ilişki';
$strAddFields = '%s alan(lar) ekle';
$strAddHeaderComment = 'Başlığa yorum ekle (\\n satır atlar)';
$strAddIfNotExists = 'IF NOT EXISTS ekle';
$strAddIntoComments = 'Yorumlara ekle';
$strAddNewField = 'Yeni alan ekle';
$strAddPrivilegesOnDb = 'Bir sonraki veritabanı üzerinde yetki ekle';
$strAddPrivilegesOnTbl = 'Bir sonraki tablo üzerinde yetki ekle';
$strAddSearchConditions = 'Arama durumu ekle ("where" komutu için):';
$strAddToIndex = '%s indeks satırı ekle';
$strAddUserMessage = 'Yeni bir kullanıcı eklediniz.';
$strAddUser = 'Yeni kullanıcı ekle';
$strAdministration = 'Yönetim';
$strAffectedRows = 'Etkilenen satırlar:';
$strAfterInsertBack = 'Önceki sayfaya geri dön';
$strAfterInsertNewInsert = 'Yeni kayıt ekle';
$strAfterInsertNext = 'Sonraki satırı düzenle';
$strAfterInsertSame = 'Bu sayfaya geri dön';
$strAfter = '%s tablosundan sonra';
$strAllTableSameWidth = 'Bütün tabloları aynı genişlikte göster';
$strAll = 'Tümü';
$strAlterOrderBy = 'Tablo sıralamasını şuna göre değiştir';
$strAnalyzeTable = 'Tabloyu analiz et';
$strAndThen = 've';	
$strAnd = 'Ve';
$strAnIndex = '%s üzerinde yeni bir indeks eklendi';
$strAny = 'Herhangi';
$strAnyHost = 'Herhangi sunucu';
$strAnyUser = 'Herhangi kullanıcı';
$strApproximateCount = 'Tahmini olmalı. Ayrıntılı bilgi için 3.11 FAQ\' süne bakınız ';
$strAPrimaryKey = '%s üzerinde birincil indeks eklendi';
$strArabic = 'Arapça';
$strArmenian = 'Ermenice';
$strAscending = 'Artan';
$strAtBeginningOfTable = 'Tablo başında';
$strAtEndOfTable = 'Tablo sonunda';
$strAttr = 'Özellikler';
$strAutodetect = 'Otomatik';
$strAutomaticLayout = 'Otomatik düzen';

$strBack = 'Geri';
$strBaltic = 'Baltık';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = 'Binari';
$strBinaryDoNotEdit = 'Binari - düzenlemeyiniz';
$strBinaryLog = 'Binary kayıt';  
$strBinLogEventType = 'Kayıt olay tipi';  
$strBinLogInfo = 'Bilgi';  
$strBinLogName = 'Kayıt ismi';
$strBinLogOriginalPosition = 'Orjinal kayıt yeri';
$strBinLogPosition = 'Kayıt yeri';  
$strBinLogServerId = 'Sunucu ID\`si'; 
$strBookmarkAllUsers = 'Bütün kullanıcıların bu bookmark\'a erişimlerine izin ver';
$strBookmarkDeleted = 'Bookmark silindi.';
$strBookmarkLabel = 'Etiket';
$strBookmarkOptions = 'Yer imi seçenekleri';
$strBookmarkQuery = ' SQL sorgusu';
$strBookmarkThis = 'Bu SQL sorgusunu işaretle';
$strBookmarkView = 'Sadece gözat';
$strBrowseForeignValues = 'Foreign(yabancı) değerleri tara';
$strBrowse = 'Tara';
$strBufferPool = 'Ara Bellek Havuzu';  
$strBufferPoolUsage = 'Ara Bellek Havuzu Kullanımı';   
$strBulgarian = 'Bulgarca';
$strBusyPages = 'Meşgul Sayfalar';   
$strBzError = 'phpMyAdmin dump dosyasını  bu php versiyonundaki bozuk bir Bz2 uzantısı nedeniyle sıkıştırımadı. phpMyAdmin dizinindeki configurasyon dosyası içindeki  <code>$cfg[\'BZipDump\']</code>  yönergesini <code>FALSE</code> \'a değiştirmeniz gerekmektedir. Bz2 sıkıştırma özelliklerini kullanmak istiyorsanız ,bir sonraki php sürümüne güncelleme yapmanız gerekmektedir.php hata raporu %s\' e bakınız ';
$strBzip = '"bzip"';

$strCalendar = 'Takvim';
$strCannotLogin = 'MySQL seçenekleri';
$strCantLoadRecodeIconv = 'Karakter seti dönüşümü için gerekli olan Iconv veya recode uzantılarını yükleyenemiyor.  Php\'nin bu uzantılara izin vermesini sağlayın veya phpMyAdmin içinde karakter dönüşümünü devre dışı bırakınız...';
$strCantLoad = '%s uzantısı yüklenemiyor,<br />PHP konfigurasyon dosyasını kontrol ediniz.';
$strCantRenameIdxToPrimary = 'Indeks\'i PRIMARY olarak adlandırımazsınız!';
$strCantUseRecodeIconv = 'Uzantı raporları yüklenmişken , ne iconv,ne libinconv,ne de recode_string fonksiyonu  kullanılamaz.  Php ayarlarınızı kontrol ediniz.';
$strCardinality = 'En önemli';
$strCarriage = 'Enter Karakteri: \\r';
$strCaseInsensitive = 'büyük küçük harf duyarsız';
$strCaseSensitive = 'büyük küçük harf duyarlı';
$strCentralEuropean = 'Orta Avrupa';
$strChangeCopyMode = 'Aynı yetkilerle yeni bir kullanıcı yarat ve :';
$strChangeCopyModeCopy = 'eski kullanıcıyı muhafaza et.';
$strChangeCopyModeDeleteAndReload = 'eski kullanıcıyı kullanıcı tablolarından sil ve sonra yetkileri yeniden yükle.';
$strChangeCopyModeJustDelete = 'eski kullanıcıyı kullanıcı tablolarından sil.';
$strChangeCopyModeRevoke = 'eskiden kalan bütün aktif yetkileri iptal et ve sil.';
$strChangeCopyUser = 'Login bilgisini değiştir / Kullanıcı kopyala';
$strChange = 'Değiştir';
$strChangeDisplay = 'Görmek istediğiniz alanı seçiniz';
$strChangePassword = 'Şifre Değiştir';
$strCharset = 'Karakter seti';
$strCharsetOfFile = 'Dosyanın karakter seti:';
$strCharsetsAndCollations = 'Karakter setleri ve  karşılaştırmalar';
$strCharsets = 'Karakter setleri';
$strCheckAll = 'Tümünü seç';
$strCheckOverhead = 'Baştan aşağıya kontrol et';
$strCheckOverhead = 'Fazlalık (Overhead) tabloları kontrol et';
$strCheckPrivsLong = '&quot;%s&quot; veritabanı için yetkileri kontrol et.';
$strCheckPrivs = 'İmtiyazları kontrol et';
$strCheckTable = 'Tabloyu kontrol et';
$strChoosePage = 'Lütfen düzenlemek istediğiniz sayfayı seçin';
$strColComFeat = 'Sütun yorumları gösteriliyor';
$strCollation = 'Karşılaştırma';
$strColumnNames = 'Sütun adları';
$strColumnPrivileges = 'Sütuna özgü yetkiler';
$strCommand = 'Komut';
$strCommentsForTable = 'TABLO YORUMLARI';
$strComments = 'Sütun yorum,ilişki ve MIME tiplerini içer.';
$strCompatibleHashing = 'MySQL&nbsp;4.0 uyumlu'; 
$strCompleteInserts = 'Her INSERT komutunda sütun adlarını ekle';
$strCompression = 'Sıkıştırma';
$strConfigFileError ='phpMyAdmin konfigurasyon dosyanızı okuyamadı....<br /> Bu php yorumlama hatası bulduğu zaman veya dosyayı bulamadığı zaman meydana gelebilir..<br /> Lütfen aşağıdaki linki kullanarak dosyayı direkt olarak çağırın ve aldığınız php hata mesajlarını okuyunuz.Çoğu durumda herhangi bir yerde tırnak veya noktalı virgül eksiktir<br /> Boş bir sayfayla karşılaşırsanız ,herşey yolunda demektir.';
$strConfigureTableCoord = ' Lütfen %s tablosu için koordinatları yapılandırınız';
$strConnectionError = 'Bağlanamıyor: geçersiz ayarlar.';
$strConnections = 'Bağlantılar';
$strConstraintsForDumped = 'Dökümü yapılmış tablolar için kısıtlamalar';
$strConstraintsForTable = 'Tablo için kısıtlamalar';
$strCookiesRequired = 'Cookieler açık olmalıdır.';
$strCopyDatabaseOK = '%s veritabanı %s\` e kopyalandı.'; 
$strCopy = 'Kopyala';
$strCopyTableOK = '%s tablosu %s üzerine kopyalandı.';
$strCopyTableSameNames = 'Tabloyu aynısına kopyalayamıyor!';
$strCopyTable = 'Tabloyu (veritabanı<b>.</b>tablo) kopyala :';
$strCouldNotKill = 'phpMyAdmin  %s işlemini kapatamadı. Büyük ihtimalle daha önceden kapatılmış.';
$strCreateDatabaseBeforeCopying = 'Kopyalamadan önce CREATE DATABASE (Veritabanı Yarat)';
$strCreate = 'Git';
$strCreateIndex = '%s. sütunda yeni bir indeks oluştur.';
$strCreateIndexTopic = 'Yeni bir indeks oluştur';
$strCreateNewDatabase = 'Yeni veritabanı oluştur';
$strCreateNewTable = '<b>%s</b> veritabanı üzerinde yeni bir tablo oluştur';
$strCreatePage = 'Yeni sayfa oluştur';
$strCreatePdfFeat = 'PDF\'lerin oluşturulması';
$strCreationDates = 'Oluşturulma/Güncelleme/Kontrol tarihleri';
$strCriteria = 'Kriter';
$strCroatian = 'Hırvatça';
$strCSVOptions = 'CSV seçenekleri';
$strCyrillic = 'Kiril';
$strCzech = 'Çekçe';
$strCzechSlovak = 'Çekçe-Slovakça';

$strDanish = 'Danimarkaca';
$strDatabaseEmpty = 'Veritabanı adı boş!';
$strDatabaseExportOptions = 'Veritabanı dönüşüm ayarları';
$strDatabaseHasBeenDropped = '%s veritabanı kaldırıldı.';
$strDatabaseNoTable = 'Bu veritabanı tablo içermiyor!';
$strDatabasesDropped = '%s veritabanları başarıyla kaldırıldı.';
$strDatabasesStatsDisable = 'İstatistikleri kapat';
$strDatabasesStatsEnable = 'İstatistikleri aç';
$strDatabasesStatsHeavyTraffic = 'Not: Burada veritabanı istatistiklerini  açmak Web Sunucusu ile MySQL arasında yüksek trafiğe yol açabilir.';
$strDatabasesStats = 'Veritabanı istatistikleri';
$strDatabases = 'Veritabanları';
$strDatabase = 'Veritabanı';
$strDataDict = 'Veri sözlüğü';
$strDataOnly = 'Sadece veri';
$strDataPages = 'Veri içeren sayfalar';   
$strData = 'Veri';
$strDBComment = 'Veritabanı yorumu:';
$strDBCopy = 'Veritabanını şuraya kopyala:';  
$strDBGContextID = 'İçerik ID';
$strDBGContext = 'İçerik';
$strDBGHits = 'Girişler(hit)';
$strDBGLine = 'Satır';
$strDBGMaxTimeMs = 'Max zaman, ms';
$strDBGMinTimeMs = 'Min zaman, ms';
$strDBGModule = 'Modül';
$strDBGTimePerHitMs = 'Zaman/Giriş, ms';
$strDBGTotalTimeMs = 'Toplam zaman, ms';
$strDbPrivileges = 'Veritabanına özgü yetkiler';
$strDBRename = 'Veritabanını yeniden adlandır';
$strDbSpecific = 'Veritabanına özgü';
$strDefaultEngine = '%s bu MySQL sunucusunun üzerindeki varsayılan depolama motorudur.';   
$strDefaultValueHelp = 'Varsayılan değerler için tırnak işareti veya slash koymak yerine tek değer giriniz.Mesela : a';
$strDefault = 'Varsayılan';
$strDefragment = 'Tabloyu birleştir';
$strDelayedInserts = 'Gecikmiş kayıt eklemeleri kullan';
$strDeleteAndFlushDescr = 'Bu en kısa yoldur fakat yetkileri yeniden yüklemek zaman alabilir.';
$strDeleteAndFlush = 'Kullanıcıları sonra da yetkileri sil.';
$strDeletedRows = 'Silinen satırlar:';
$strDeleted = 'Satır silindi.';
$strDelete = 'Sil';
$strDeleting = '%s siliniyor';
$strDelOld = 'Sayfada kullanılmayan tablolara verilmiş referanslar bulunuyor. Bu referansları silmek ister misiniz?';
$strDescending = 'Azalan';
$strDescription = 'Tanımlama';
$strDictionary = 'sözlük';
$strDirtyPages = 'Bozuk Sayfalar';  // not the actual translation i need some help
$strDisabled = 'Etkin değil';
$strDisableForeignChecks = 'Yabancı anahtar işaretlerini seçilemez kıl';
$strDisplayFeat = 'Özellikleri Göster';
$strDisplayOrder = 'Görünüm düzeni:';
$strDisplayPDF = 'PDF şemasını göster';
$strDoAQuery = '<br /><br />"Örnekle sorgu" yap. (joker:%) <br />';
$strDocu = 'Yardım';
$strDoYouReally = 'Aşağıdaki komutu uygulamak istediğinizden emin misiniz? ';
$strDropDatabaseStrongWarning = 'Bütün bir veritabanını YOK ETMEK üzeresiniz!';
$strDrop = 'Kaldır';
$strDropSelectedDatabases = 'Seçili veritabanlarını kaldır';
$strDropUsersDb = 'Kullanıcılarla aynı isimlerde olan veritabanlarını kaldır.';
$strDumpingData = 'Tablo döküm verisi';
$strDumpSaved = 'Döküm dosyası %s dosyasına kaydedildi';
$strDumpXRows = 'Satır sayısı : %s    %s .satırdan başlayarak.';
$strDynamic = 'değişken';

$strEdit = 'Düzenle';
$strEditPDFPages = ' PDF Sayfalarını düzenle';
$strEditPrivileges = 'Öncelikleri Düzenle';
$strEffective = 'Efektif';
$strEmpty = 'Boşalt';
$strEmptyResultSet = 'MySQL boş bir sonuç kümesi döndürdü ( sıfır satır).';
$strEnabled = 'Etkin';
$strEncloseInTransaction = 'İşlemlerde dönüştürü ekle';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnd = 'Son';
$strEngineAvailable = '%s bu MySQL sunucusu üzerinde bulunmaktadır.';  $strEngineUnsupported = 'Bu MySQL sunucusu %s depolama motorunu desteklememektedir.'; 
$strEngineDisabled = '%s bu MySQL sunucusu için devre dışı bırakılmıştır.';
$strEngines = 'Motorlar';   
$strEnglishPrivileges = ' Not: MySQL  yetki adları İngilizce olarak belirtilmiştir ';
$strEnglish = 'İngilizce';
$strError = 'Hata';
$strEscapeWildcards = '_ ve % jokerleri harfi harfine kullanılmak isteniyorsa \ ile beraber kullanılmalıdır.';
$strEstonian = 'Estonyaca';
$strExcelEdition = 'Excel tipi';
$strExcelOptions = 'Excel ayarları';
$strExecuteBookmarked = 'İşaretlenmiş sorguyu çalıştır';
$strExplain = 'SQL\'i açıkla';
$strExport = 'Dönüştür';
$strExtendedInserts = 'Tablo ismini ve INSERT deyimini sadece bir kez kullan';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Başarısız denemeler';
$strField = 'Alan';
$strFieldHasBeenDropped = '%s alanı kaldırılmıştır';
$strFields = 'Alanlar';
$strFieldsEmpty = ' Alan sayısı boş! ';
$strFieldsEnclosedBy = 'Kapatma karakteri';
$strFieldsEscapedBy = 'Kaçış karakteri';
$strFieldsTerminatedBy = 'Alan sonu karakteri';
$strFileAlreadyExists = '%s dosyası zaten serverda mevcut, dosya adını değiştirin veya üzerine yaz seçeneğini seçin! ';
$strFileCouldNotBeRead = 'Dosya okunamadı';
$strFileNameTemplate = 'Dosya ismi şablonu';
$strFileNameTemplateHelp = 'Veritabanı ismi için __DB__ , tablo ismi için __TABLE__ ve  zaman bildirimi için %sherhangi bir strftime%s değeri kullanın,uzantı otomatik olarak eklenecek,herhangi diğer bir metin korunacaktır.';
$strFileNameTemplateRemember = 'şablonu hatırla';
$strFixed = 'Sabit';
$strFlushPrivilegesNote = 'Not: phpMyAdmin kullanıcıların yetkilerini direkt olarak MySQL\'ün yetki tablolarından alır.Bu tabloların içerikleri eğer elle  değişiklik yapılmışsa sunucunun kullandığı yetkilerden farklı olabilir.Bu durumda devam etmeden önce %syetkileri yeniden yüklemeniz gerekir%s .';
$strFlushTable = 'Tabloyu yeniden yükle("FLUSH")';
$strFormat = 'Biçim';
$strFormEmpty = 'Form\'da eksik değer !';
$strFreePages = 'Serbest Sayfalar';   
$strFullText = 'Tüm metinler';
$strFunction = 'Fonksiyon';

$strGenBy = 'üretildi:';
$strGeneralRelationFeat = 'Genel ilişki özellikleri';
$strGenerate = 'Oluştur';
$strGeneratePassword = 'Şifre Oluştur';
$strGenTime = 'Çıktı Tarihi';
$strGeorgian = 'Gürcüce';
$strGerman = 'Almanca';
$strGlobal = 'genel';
$strGlobalPrivileges = 'Global yetkiler';
$strGlobalValue = 'Global değer';
$strGo = 'Git';
$strGrantOption = 'Hak';
$strGreek = 'Yunanca';
$strGzip = '"gzip"';

$strHasBeenAltered = 'düzenlendi.';
$strHasBeenCreated = 'yaratıldı.';
$strHaveToShow = 'Görüntülemek için en az bir sütun seçmelisiniz';
$strHebrew = 'İbranice';
$strHexForBinary = 'Binari alanları için onaltılık sayı sistemini kullan.';
$strHome = 'Ana Sayfa';
$strHomepageOfficial = 'phpMyAdmin Web Sayfası';
$strHostEmpty = 'Sunucu ismi alanı boş!';
$strHost = 'Sunucu';
$strHungarian = 'Macarca';

$strIcelandic = 'İzlandaca';
$strId = 'ID';
$strIdxFulltext = 'Tüm metinler';
$strIfYouWish = 'Eğer bir tablo\'nun sadece bazı sütunlarını yüklemek istiyorsanız,virgüllerle ayrılmış bir alan listesi belirtiniz.';
$strIgnoreInserts = 'Kayıt eklemeleri yoksayı kullan';
$strIgnore = 'Yoksay';
$strIgnoringFile = '%s dosyasını yoksayıyor';
$strImportDocSQL = 'docSQL dosyalarını dönüştür ';
$strImportFiles = 'Dosyaları dönüştür';
$strImportFinished = 'Dönüştürme bitti';
$strIndexes = 'İndeksler';
$strIndexHasBeenDropped = '%s indeks\'i silindi.';
$strIndexName = 'İndeks ismi :';
$strIndexType = 'İndeks tipi :';
$strIndexWarningMultiple = '`%s` sütunu için birden fazla %s anahtarı yaratıldı. ';
$strIndexWarningPrimary = 'PRIMARY ve INDEX anahtarlarının ikisine birden `%s` sütunu için değer verilemez.';
$strIndexWarningTable = '`%s` tablosunun indexleri ile ilgili sorunlar';
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';
$strIndex = 'İndeks';
$strInnoDBAutoextendIncrement = 'Artış miktarını otomatik olarak arttır';   
$strInnoDBAutoextendIncrementDesc = ' Otomatik genişleyen tablo boyutu boş olduğunda otomatik genişleyen tablo boşluğunun boyutun artış miktarı.';  
$strInnoDBDataFilePath = 'Veri dosyaları';  
$strInnoDBDataHomeDirDesc = 'InnoDB veri dosyaları için dizin yolunun ortak kullanılan kısmı.'; 
$strInnoDBDataHomeDir = 'Veri ana dizini ';  
$strInnodbStat = 'InnoDB durumu';
$strInsecureMySQL = 'Konfigurasyon dosyanız (şifresiz root) varsayılan MySQL yetki dosyasıyla aynen uyuşan ayarlar içeriyor.MySQL sunucunuz bu varsayılan ayarlarla çalışıyor,dışardan girişe açık,ve bu güvenlik açığını hemen düzeltmeniz gerekmektedir.';
$strInsertAsNewRow = 'Yeni satır olarak ekle';
$strInsertBookmarkTitle = 'Lütfen bookmark başlığını ekleyin'; 
$strInsertedRowId = 'Satır id\'si eklendi:';
$strInsertedRows = 'Eklenen satırlar:';
$strInsert = 'Ekle';
$strInsertNewRow = 'Yeni satır ekle';
$strInsertTextfiles = 'Tablo içine metin dosyası ekle';
$strInstructions = 'Talimatlar';
$strInternalNotNecessary = '* InnoDb\'nin içinde zaten bir iç ilişki  var ise gerekli değildir.';
$strInternalRelations = 'İç ilişkiler';
$strInUse = 'kullanımda';
$strInvalidColumnCount = 'Sütun sayısı sıfırdan büyük olmalı.';
$strInvalidFieldAddCount = 'En azından bir alan eklemeniz gerekmektedir..';
$strInvalidFieldCount = 'Tablonun en az bir alanı olmalı.';
$strInvalidRowNumber = '%d geçerli bir satır sayısı değil.';

$strJapanese = 'Japonca';
$strJumpToDB = '&quot;%s&quot; veritabanına git.';
$strJustDeleteDescr = '&quot;silinmiş&quot; kullanıcılar, yetkiler yeniden yüklenmedikçe ,hala sunucuya normaldeki gibi erişilebilecek ';
$strJustDelete = 'Kullanıcıları yetki tablolarından sil .';

$strKeepPass = 'Şifreyi değiştirme';
$strKeyname = 'Anahtar ismi';
$strKill = 'Kapat';
$strKorean = 'Korece';

$strLandscape = 'Peyzaj';
$strLatchedPages = 'Mandallanmış Sayfalar';  //also this
$strLatexCaption = 'Tablo başlığı';
$strLatexContent = '__TABLE__ tablosunun içeriği';
$strLatexContinuedCaption = 'devam eden tablo başlığı';
$strLatexContinued = '(devam eden)';
$strLatexIncludeCaption = 'Tablo başlığını içer';
$strLatexLabel = 'Etiket anahtarı';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX seçenekleri';
$strLatexStructure = '__TABLE__ tablosunun yapısı';
$strLatvian = 'Litvanyaca';
$strLengthSet = 'Boyut/Değerler*';
$strLimitNumRows = 'Sayfa başına kayıt sayısı :';
$strLineFeed = 'Satır: \\n';
$strLinesTerminatedBy = 'Satır sonu';
$strLinkNotFound = 'Link bulunamadı';
$strLinksTo = 'Linkler->';
$strLithuanian = 'Litvanyaca';
$strLoadExplanation = 'En iyi yöntem varsayılan olarak işaratlenmiş,fakat hata olursa değiştirebilirsiniz.';
$strLoadMethod = 'YÜKLEME yöntemi';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Dosyadan yükle';
$strLoginInformation = 'Login bilgisi';
$strLogin = 'Login';
$strLogout = 'Çıkış';
$strLogPassword = 'Şifre:';
$strLogServer = 'Sunucu';
$strLogUsername = 'Kullanıcı Adı:';
$strLongOperation = 'Bu işlem çok uzun sürebilir. Devam etmek istediğiniz emin misiniz?';

$strMaximumSize = 'En büyük boyut: %s%s';
$strMbExtensionMissing = 'mbstring PHP uzantısı bulunamadı ve multibyte karakter seti kullanmaktasınız. Eğer mbstring uzantısı bulunmazsa phpMyAdmin karakter dizilerini düzgün bir şekilde bölemeyeceği için beklenmeyen sonuçlar oluşabilir.';
$strMbOverloadWarning = 'mbstring.func_overload PHP konfigürasyon dosyanızda etkinleştirilmiş durumda. Bu seçenek phpMyAdmin ile uyumsuzluk göstermekte ve bazı verilerin bozulmasına yol açabilir!';
$strMIME_available_mime = 'Uygun MIME-tipleri';
$strMIME_available_transform = 'Uygun dönüşümler';
$strMIME_description = 'Tanımlama';
$strMIME_MIMEtype = 'MIME-tip';
$strMIME_nodescription = 'Bu dönüşüm için uygun bilgi bulunmamaktadır.<br />Lütfen yazara %s ne yapar diye sorun';
$strMIME_transformation_note = 'Uygun dönüşüm seçeneklerinin listesi ve onların  MIME-tip dönüşümleri için,  %sdönüşüm tanımlamarı%s\'na tıklayın';
$strMIME_transformation_options = 'Dönüşüm seçenekleri';
$strMIME_transformation_options_note = 'Lütfen dönüşüm seçenekleri için değerleri bu şekili kullanarak giriniz: \'a\',\'b\',\'c\'...<br />Backslash ("\") veya tek tırnak ("\'") kullamanız gerekiyorsa, şu şekilde kullanın : \'\\\\xyz\' veya \'a\\\'b\').';
$strMIME_transformation = 'Tarayıcı dönüşümü';
$strMIMETypesForTable = 'TABLO MIME TİPLERİ';
$strMIME_without = 'İtalik olarak yazılmış MIME-tipleri ayrı bir dönüşüm fonksiyonuna sahip değildir.';
$strModifications = 'Değişiklikler kaydedildi';
$strModify = 'Değiştir';
$strModifyIndexTopic = 'Indeks düzenle';
$strMoreStatusVars = 'Diğer durum değişkenleri:';
$strMoveTableOK = '%s tablosu %s üzerine taşındı.';
$strMoveTableSameNames = 'Tabloyu aynısına taşıyamıyor!';
$strMoveTable = 'Tabloyu (veritabanı<b>.</b>tablo) taşı :';
$strMultilingual = 'çoklu dil';
$strMustSelectFile = 'Eklemek istediğiniz dosyayı seçmeniz gerekir.';
$strMyISAMDataPointerSizeDesc = 'MAX_ROWS seçeneği belirtilmediği durumlarda MyISAM tabloları için CREATE TABLE komutuyla kullanılacak olan varsayılan işaretçi boyutu (Byte olarak).';  
$strMyISAMDataPointerSize = 'Veri işaretçi boyutu';   
$strMyISAMMaxExtraSortFileSizeDesc = 'Hızlı MyISAM indeksi oluşturulması sırasında kullanılan geçici dosya belirtilen boyutta anahtar önbellek kullanılması durumunda oluşacak olan dosyadan büyük olacaksa, anahtar önbellek metodunu seçiniz.';  
$strMyISAMMaxExtraSortFileSize = 'İndeks oluşturmada kullanılan maksimum geçici dosyalar boyutu'; 
$strMyISAMMaxSortFileSizeDesc = 'MySQL\in bir MyISAM indeksini yeniden oluştururken kullandığı geçici dosyanın maksimum boyutu (REPAIR TABLE, ALTER TABLE, ya da LOAD DATA INFILE sırasında).';  
$strMyISAMMaxSortFileSize = 'Maksimum geçici sıralama dosyaları boyutu.';
$strMyISAMRecoverOptions = 'Otomatik Kurtarma Modu';   $strMyISAMRecoverOptionsDesc = '-myisam-recover şeklinde sunucu başlangıç komutu olarak ayarlanabilen ve çöken MyISAM tablolarını otomatik olarak kurtarmak amacıyla kullanılan mod,.';   
$strMyISAMRepairThreadsDesc = 'Bu değer 1\den büyükse, işlem sıralama yoluyla yapılan Onarım (Repair) sırasında MyISAM tablosu indeksleri (her bir indeks kendi işlemi içinde ) paralel olarak yaratılır. ';  
$strMyISAMRepairThreads = 'İşlemleri Onar';   
$strMyISAMSortBufferSizeDesc = 'Bir REPAIR TABLE komutuyla MyISAM indeksleri sıralanırken ya da CREATE INDEX ya da ALTER TABLE komutuyla indekslerin oluşturulması sırasında için ayrılan ara bellek miktarı.';  
$strMyISAMSortBufferSize = 'Listeleme ara bellek boyutu';   
$strMySQLCharset = 'MySQL karakter seti';
$strMySQLConnectionCollation = 'MySQL bağlantı karşılaştırması';
$strMySQLReloaded = 'MySQL yeniden yüklendi.';
$strMySQLSaid = 'MySQL çıktısı: ';
$strMySQLServerProcess = ' MySQL %pma_s1%   %pma_s2%  üzerinde  %pma_s3% olarak çalışıyor';
$strMySQLShowProcess = 'İşlemleri göster';
$strMySQLShowStatus = 'MySQL çalışma zamanı bilgisini göster';
$strMySQLShowVars = 'MySQL sistem değişkenlerini göster';

$strName = 'İsim';
$strNeedPrimaryKey = 'Bu tablo için birincil anahtar tanımlamanız gerekir.';
$strNext = 'Sonraki';
$strNoActivity = '%s veya daha fazla saniye boyunca hiçbir işlem yapılmadı, lütfen yeniden giriş yapınız';
$strNoDatabasesSelected = 'Veritabanı seçilmedi.';
$strNoDatabases = 'Veritabanı yok';
$strNoDescription = 'Tanımlama yok';
$strNoDetailsForEngine = 'Bu depolama motoru için detaylı durum bilgisi bulunmamaktadır.';   
$strNoDropDatabases = '"DROP DATABASE" cümlesi burada kullanılamaz.';
$strNoExplain = 'SQL açıklamasını yapma';
$strNoFrames = 'phpMyAdmin frame destekli bir tarayıcı ile daha iyi çalışmaktadır...';
$strNo = 'Hayır';
$strNoIndex = 'Indeks tanımlanmadı!';
$strNoIndexPartsDefined = 'Indeks kısmı tanımlanmadı!';
$strNoModification = 'Değişiklik yok';
$strNone = 'Hiçbiri';
$strNoOptions = 'Bu düzenin seçeği yok';
$strNoPassword = 'Şifre yok';
$strNoPermission = 'Web sunucusu  %s dosyasını kaydetmek için izne sahip değil.';
$strNoPhp = ' PHP kodsuz';
$strNoPrivileges = 'Buna yetkiniz yok';
$strNoQuery = 'SQL sorgusu yok!';
$strNoRights = 'Burada bulunmak için yeterli haklara sahip değilsiniz!';
$strNoRowsSelected = 'Satır seçilmedi';
$strNoSpace = '%s dosyasını kaydetmek için yeterli alan yok.';
$strNoTablesFound = 'Veritabanında tablo bulunamadı.';
$strNoThemeSupport = 'Tema desteği bulunmuyor,lütfen ayarları ve/veya %s dizinindeki temalarınızı kontrol ediniz';
$strNotNumber = 'Lütfen bir sayı giriniz!';
$strNotOK = 'Tamam değil';
$strNotSet = '<b>%s</b> tablosu bulunamadı veya %s içinde tanımlanmadı';
$strNoUsersFound = 'Kullanıcı(lar) bulunamadı.';
$strNoValidateSQL = 'SQL doğrulamasını yapma';
$strNull = 'Boş';
$strNumberOfFields = 'Alan Sayısı';
$strNumSearchResultsInTable = '<b><font color=\'blue\'>%s</font></b> ( <b>%s</b> tablosu içinde aramanıza uyan kayıt sayısı ) ';
$strNumSearchResultsTotal = 'Toplam: %s eşleşim';
$strNumTables = 'Tablolar';

$strOftenQuotation = 'Sık kullanılan aktarma işaretleri.SEÇİME BAĞLI,sadece <b>char</b> ve <b>varchar</b> alanlarının kapatma karakteri ile çevreleneceği anlamına gelir..';
$strOK = 'Tamam';
$strOperations = 'İşlemler';
$strOperator = 'İşlemci';
$strOptimizeTable = 'Tabloyu optimize et';
$strOptionalControls = 'Özel karakterleri yazmak ve okumak için kontroller.Opsiyonel';
$strOptionally = 'Seçime Bağlı';
$strOr = 'veya';
$strOverhead = 'Kullanılamayan Veri';
$strOverwriteExisting = 'Mevcut dosyaların üzerine yaz!';

$strPageNumber = 'Sayfa numarası:';
$strPagesToBeFlushed = 'Yeniden yüklenecek sayfaları göster (flush)'; 
$strPaperSize = 'Kağıt boyu';
$strPartialText = 'Kısmi Metinler';
$strPasswordChanged = '%s için şifre başarıyla değiştirildi.';
$strPasswordEmpty = 'Şifre alanı doldurulmadı!';
$strPasswordHashing = 'Şifre Hash yöntemi';  
$strPasswordNotSame = 'Girilen şifreler uyuşmuyor!';
$strPassword = 'Şifre';
$strPdfDbSchema = ' "%s" veritabanının şeması - Sayfa %s';
$strPdfInvalidTblName = ' "%s" tablosu bulunamıyor !';
$strPdfNoTables = 'Tablo yok';
$strPerHour = 'saat başına';
$strPerMinute = 'dakika başına';
$strPerSecond = 'saniye başına';
$strPersian = 'Farsça';
$strPhoneBook = 'telefon defteri';
$strPHP40203 = ' Ciddi bir multi-byte karakter dizisi (mbstring) hatasına sahip olan PHP 4.2.3 kullanıyorsunuz,. PHP hata raporu 19404\' e bakınız. Bu sürümün phpMyAdmin\'le kullanılması önerilmez.';
$strPhp = 'PHP kodu oluştur';
$strPHPVersion = 'PHP Sürümü';
$strPmaDocumentation = 'phpMyAdmin yardım';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt>\' nin değeri  konfigurasyon dosyasının içinde verilmelidir!';
$strPolish = 'Lehce';
$strPortrait = 'Portre';
$strPos1 = 'Başlangıç';
$strPrevious = 'Önceki';
$strPrimary = 'Birincil';
$strPrimaryKeyHasBeenDropped = 'Birincil anahtar silindi';
$strPrimaryKeyName = 'PRIMARY KEY TEK olmalıdır!';
$strPrimaryKeyWarning = '# PRIMARY <b>sadece</b> birincil bir anahtarın ismi <b>olmalıdır!</b>';
$strPrintViewFull = 'Yazıcı görüntüsü (tüm metin)';
$strPrintView = 'Yazıcı görüntüsü';
$strPrint = 'Yazdır';
$strPrivDescAllPrivileges = 'GRANT hariç tüm yetkileri içerir.';
$strPrivDescAlter = 'Varolan tablonun yapısının değiştirilmesine izin verir.';
$strPrivDescCreateDb = 'Yeni veritabanları ve tabloların oluşturulmasına izin verir.';
$strPrivDescCreateTbl = 'Yeni tabloların oluşturulmasına izin verir.';
$strPrivDescCreateTmpTable = 'Geçici tablolara oluşturulmasına izin verir.';
$strPrivDescDelete = 'Veri silinmesine izin verir.';
$strPrivDescDropDb = 'Veritabanları ve tabloların kaldırılmasına izin verir.';
$strPrivDescDropTbl = 'Tabloların kaldırılmasına izin verir.';
$strPrivDescExecute = 'Kaydedilmiş yordamların çalıştırılmasına izin verir.; Bu MySQL sürümünde etkisi yoktur.';
$strPrivDescFile = 'Data import ve export\'una izin verir.';
$strPrivDescGrant = 'İmtiyaz tablolarını yeniden yüklemeden yeni kullanıcı ve yetki eklenmesine izin verir.';
$strPrivDescIndex = 'İndekslerin yaratılmasına ve kaldırılmasına izin verir.';
$strPrivDescInsert = 'Verinin eklenmesine ve yer değiştirilmesine izin verir.';
$strPrivDescLockTables = 'Geçerli işlem  için tabloların kilitlenmesine izin verir.';
$strPrivDescMaxConnections = 'Kullanıcının saat başına açabileceği bağlantıyı sınırlar.';
$strPrivDescMaxQuestions = 'Kullanıcının saat başına sunucuya gönderebileceği sorgu sayısını sınırlar.';
$strPrivDescMaxUpdates = 'Kullanıcının,saat başına çalıştırabileceği,herhangi bir tablo veya veritabanı değiştiren  komut sayısını sınırlar.';
$strPrivDescProcess3 = 'Diğer kullanıcıların işlemlerinin kapatılmasına izin verir.';
$strPrivDescProcess4 = 'İşlem listesindeki bütün sorguların görüntülenmesine izin verir.';
$strPrivDescReferences = 'Bu MySQL sürümünde etkisi yoktur.';
$strPrivDescReload = 'Sunucu ayarlarının yeniden yüklenmesine ve önbelleğin silinmesine izin verir';
$strPrivDescReplClient = 'Kullanıcılara Slave ve Master\'ların nerede olduğunu sorma  hakkını verir.';
$strPrivDescReplSlave = 'Kopya slave\'ler için gerekli.';
$strPrivDescSelect = 'Veri okunmasına izin ver.';
$strPrivDescShowDb = 'Bütün veritabanları listesine erişim verir.';
$strPrivDescShutdown = 'Sunucunun kapatılmasına izin ver.';
$strPrivDescSuper = 'Maksimum bağlantı sayısı aşılsa bile bağlanmasına izin ver;Global değişkenleri saptamak veya diğer kullanıcıların işlemlerini sonlandırmak  gibi  bir çok yönetim işlemi için gereklidir.';
$strPrivDescUpdate = 'Veri değiştirilmesine izin ver.';
$strPrivDescUsage = 'İmtiyaz yok.';
$strPrivilegesReloaded = 'Ayrıcalıklar başarıyla yüklendi.';
$strPrivileges = 'İmtiyazlar';
$strProcesslist = 'İşlem listesi';
$strPutColNames = 'İlk satırda alan isimlerini koy';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = ' Sorgula';
$strQueryFrame = 'Sorgu penceresi';
$strQueryOnDb = '<b>%s</b> veritabanında SQL sorgusu&nbsp;:';
$strQuerySQLHistory = 'SQL geçmişi';
$strQueryStatistics = '<b>Sorgu istatistikleri</b>: Başlangıçtan bu yana sunucuya <b>%s</b> sorgu gönderildi.';
$strQueryTime = 'Sorgu  %01.4f san sürdü';
$strQueryType = 'Sorgu şekli';
$strQueryWindowLock = 'Pencere dışından bu sorgunun üzerine yazma';

$strReceived = 'Alındı';
$strRecords = 'Kayıtlar';
$strReferentialIntegrity = 'Referans bütünlüğünü kontrol et.';
$strRefresh = 'Yenile';
$strRelationalSchema = 'İlişki şeması';
$strRelationNotWorking = 'İlişkili tablolarla çalışmada kullanılan ekstra özellikler kapatıldı.Nedenini öğrenmek için %sburaya%s tıklayınız...';
$strRelationsForTable = 'TABLO İLİŞKİLERİ';
$strRelations = 'İlişkiler';
$strRelationView = 'İlişki görünümü';
$strReloadFailed = 'MySQL yeniden yüklenmesi gerçekleştirilemedi.';
$strReloadingThePrivileges = 'İmtiyazları yeniden yüklüyor';
$strReloadMySQL = 'MySQL\' i yeniden yükle';
$strRemoveSelectedUsers = 'Seçili kullanıcıları kaldır';
$strRenameDatabaseOK = '%s veritabanı %s olarak yeniden adlandırıldı';
$strRenameTableOK = '%s tablosu %s olarak yeniden adlandırıldı';
$strRenameTable = 'Tabloyu yeniden adlandır';
$strRepairTable = 'Tablo\'yu onar';
$strReplaceNULLBy = 'NULL \' u bununla yerdeğiştir';
$strReplaceTable = 'Tablo verisini bir dosyadaki ile değiştir';
$strReplace = 'Yerdeğiştir';
$strReset = 'Sıfırla';
$strResourceLimits = 'Kaynak sınırları';
$strReType = 'Yeniden gir';
$strRevokeAndDeleteDescr = 'Kullanıcılar yeniden yüklenene kadar  hala KULLANIM ayrıcalığına  sahip olacaklar.';
$strRevokeAndDelete = 'Kullanıcılardaki tüm etkin yetkileri geçersiz kıl  ve sonra sil..';
$strRevoke = 'Geçersiz kıl';
$strRevokeMessage = '%s\'in önceliklerini kaldırdınız';
$strRomanian = 'Romence';
$strRowLength = 'Satır boyu';
$strRowsFrom = 'kayıt : Başlayacağı kayıt :';
$strRowSize = ' Satır boyutu ';
$strRowsModeFlippedHorizontal = 'yatay (döndürülmüş başlıklar)';
$strRowsModeHorizontal = 'yatay';
$strRowsModeOptions = '%s olarak göster ve %s hücre sonra başlığı tekrarla.';
$strRowsModeVertical = 'dikey';
$strRows = 'Satır';
$strRowsStatistic = 'Satır istatistiği';
$strRunning = '# %s üzerinde çalışıyor...';
$strRunQuery = 'Sorguyu çalıştır';
$strRunSQLQuery = '<b>%s</b> veritabanı üzerinde sorgu çalıştır';
$strRussian = 'Rusça';

$strSave = 'Kaydet';
$strSaveOnServer = 'Sunucuda %s dizininin içinde kaydet';
$strScaleFactorSmall = 'Çarpan faktörü sayfadaki şema için çok küçük';
$strSearch = 'Ara';
$strSearchFormTitle = 'Veritabanında ara';
$strSearchInTables = 'Tablo içinde ara :';
$strSearchNeedle = 'Aranacak kelime veya değerler ( joker: "%" ):';
$strSearchOption1 = 'kelimelerin en azından biri';
$strSearchOption2 = 'bütün kelimeler';
$strSearchOption3 = 'tam eşleşim';
$strSearchOption4 = 'normal deyim';
$strSearchResultsFor = ' "%s" %s için arama sonuçları:';
$strSearchType = '<b>BUL </b> :';
$strSecretRequired = 'Ayar dosyası için gizli bir şifre gerekiyor (blowfish_secret).';
$strSelectADb = ' Lütfen bir veritabanı seçiniz';
$strSelectAll = 'Tümünü seç';
$strSelectBinaryLog = 'Görüntülemek istediğiniz binari kaydını seçiniz';  
$strSelectFields = 'Alan seç (en az bir)';
$strSelectNumRows = 'sorgu içerisinde';
$strSelectTables = 'Tabloları seç';
$strSend = 'Dosya olarak kaydet';
$strSent = 'Gönderildi';
$strServerChoice = 'Server seçimi';
$strServerNotResponding = 'Sunucu yanıt vermiyor';
$strServerStatus = 'Çalışma bilgisi';
$strServerStatusUptime = 'Bu MySQL sunucusunun çalışma süresi : %s <br /> Başlama Zamanı: %s ';
$strServer = 'Sunucusu';
$strServerTabProcesslist = 'İşlemler';
$strServerTabVariables = 'Değişkenler';
$strServerTrafficNotes = '<b>Sunucu Yoğunluğu</b>: Bu tablolar başlama zamanından bu yana  MySQL sunucusunun network yoğunluğunu gösterir.';
$strServerVars = 'Sunucu değişkenleri ve ayarları';
$strServerVersion = 'Server sürümü';
$strSessionValue = 'Oturum değeri';
$strSetEnumVal = 'Eğer alan tipi "enum" veya "set" ise verileri şu formata göre giriniz: \'a\',\'b\',\'c\'...<br />Eğer bu değerler arasına backslash ("\") veya tek tırnak koymanız gerekirse (\'),bunun için backslash kullanın.Mesela: \'\\\\xyz\' veya \'a\\\'b\') gibi.';
$strShowAll = 'Tümünü göster';
$strShowColor = 'Rengi göster';
$strShowDatadictAs = 'Veri sözlüğü formatı';
$strShowFullQueries = 'Sorguların tümünü göster';
$strShow = 'Göster';
$strShowGrid = 'Izgarayı göster';
$strShowingRecords = 'Kayıtları gösteriyor...';
$strShowPHPInfo = 'PHP bilgisini göster';
$strShowTableDimension = 'Tabloların';
$strShowTables = 'Tabloları göster';
$strShowThisQuery = 'Sorguyu burada yine göster.';
$strSimplifiedChinese = 'Basitleştirilmiş Çince';
$strSingly = '( birer birer )';
$strSize = 'Boyut';
$strSlovak = 'Slovakça';
$strSlovenian = 'Slovence';
$strSocketProblem = '(ya da lokal MySQL sunucusu soketi düzgün bir şekilde ayarlanmamış.)';
$strSortByKey = 'Anahtara göre sırala';
$strSort = 'Sırala';
$strSpaceUsage = 'Kullanılan alan';
$strSpanish = 'İspanyolca';
$strSplitWordsWithSpace = 'Kelimelerin arasında boşluk olmalıdır (" ").';
$strSQLExportCompatibility = 'SQL\e dönüştürme uyumluluğu';
$strSQLExportType = 'Export tipi';
$strSQLOptions = 'SQL seçenekleri';
$strSQLParserBugMessage = 'SQL yorumlayıcısında bir hata bulma ihtimaliniz var.Lütfen sorgunuzu dikkatli bir şekilde gözden geçiriniz,ve tırnaklar doğru ve yanlış yazılmamış kontrol ediniz.Diğer olası hata nedenleri metin alanına alabileceği boyuttan daha büyük bir dosya yüklüyor olma ihtimalinizdir.Sorgunuzu MySQL komut satırı arayüzünde de deneyebilirsiniz..MySQL sunucu hata çıktısı,var ise,hatayı manızda size yardımcı olabilir.Hala sorunlarınız varsa veya  komut satırı arayüzü çalışırken,yorumlayıcı hata veriyorsa,lütfen SQL sorgu girişinizi hata yaratan tek bir sorguya indirgeyin,ve aşağıdaki CUT bölümü veri yığını ile birlikte hata raporunu bildiriniz:';
$strSQLParserUserError = 'SQL sorgunuzda bir hata varmış gibi gözüküyor.MySQL sunucu hata çıktısı,var ise,hatayı bulmanızda size yardımcı olabilir.';
$strSQLQuery = 'SQL sorgusu';
$strSQLResult = 'SQL sonucu';
$strSQL = 'SQL sorgusu';
$strSQPBugInvalidIdentifer = 'Geçersiz tanımlayıcı';
$strSQPBugUnclosedQuote = 'Kapatılmamış tırnak';
$strSQPBugUnknownPunctuation = 'Bilinmeyen noktalama işareti';
$strStatCheckTime = 'Son kontrol';
$strStatCreateTime = 'Oluşturulma';
$strStatement = 'Durum';
$strStatUpdateTime = 'Son güncellenme';
$strStatus = 'Durum';
$strStorageEngine = 'Depolama Motoru'; 
$strStorageEngines = 'Depolama Motorları';  
$strStrucCSV = 'CSV verisi';
$strStrucData = 'Yapı ve Veri';
$strStrucDrop = 'DROP TABLE ekle';
$strStrucExcelCSV = 'MS Excel verisi için CSV';
$strStrucNativeExcel = 'MS Excel verisi';
$strStrucOnly = 'Sadece yapı';
$strStructPropose = 'Tablo yapısını analiz et.';
$strStructure = 'Yapı';
$strSubmit = 'Onayla';
$strSuccess = 'SQL sorgunuz başarıyla çalıştırılmıştır';
$strSum = 'toplam';
$strSwedish = 'İsveçce';
$strSwitchToDatabase = 'Kopyalanmış veritabanını kullan.';  
$strSwitchToTable = 'Kopyalanmış tabloya geç';

$strTableComments = 'Tablo yorumları';
$strTableEmpty = 'Tablo ismi boş!';
$strTableHasBeenDropped = '%s tablosu kaldırılmıştır';
$strTableHasBeenEmptied = '%s tablosu boşaltılmıştır';
$strTableHasBeenFlushed = '%s tablosu başarıyla kapatılmıştır.';
$strTableMaintenance = 'Tablo bakımı';
$strTableOfContents = 'İçerik tablosu';
$strTableOptions = 'Tablo ayarları';
$strTables = '%s tablo';
$strTableStructure = 'Tablo yapısı :';
$strTable = 'Tablo:';
$strTableType = 'Tablo tipi';
$strTakeIt = 'Seç';
$strTblPrivileges = 'Tabloya özgü yetkiler';
$strTextAreaLength = 'Boyutu nedeniyle,<br /> bu alan düzenlenmeyebilir ';
$strThai = 'Thai';
$strTheContent = 'Dosyanızın içeriği eklendi.';
$strTheContents = 'Dosyanın içeriği tablonun içeriğini aynı birincil veya unique anahtar değerli sütunlar için yer değiştirir..';
$strTheme = 'Tema / Sitil';
$strTheTerminator = 'Alan bitimini belirten işaret.';
$strThisHost = 'Bu host ';
$strThisNotDirectory = 'Bu bir dizin değildi';
$strThreadSuccessfullyKilled = '%s işlemi  başarıyla sonlandırıldı.';
$strTime = 'Zaman';
$strToggleScratchboard = 'scratchboard\a geç';
$strTotal = 'toplam';
$strTotalUC = 'Toplam';
$strTraditionalChinese = 'Geleneksel Çince';
$strTraditionalSpanish = 'Geleneksel İspanyolca';
$strTraffic = 'Yoğunluk';
$strTransformation_application_octetstream__download = 'Bir alandaki binari veriyi yüklemek için link göster.İlk seçenek binari dosya adıdır.İkinci seçenek ise dosya adını içeren tablo satırırın olası alan adıdır.İkinci bir seçenek istiyorsanız ilk seçeneği boş bırakmalısınız.';
$strTransformation_application_octetstream__hex = 'Verinin hexadesimal sunumunu gösterir.';
$strTransformation_image_jpeg__inline = 'Tıklanabilir bir thumbnail gösterir; seçenekler: pixel olarak genişlik,yükseklik (orijinal oran korunur)';
$strTransformation_image_jpeg__link = 'Bu resime direkt bir link gösterir (direct blob yüklemesi...).';
$strTransformation_image_png__inline = 'jpeg resmini gör: satıriçi';
$strTransformation_text_plain__dateformat = 'Bir TIME, TIMESTAMP veya DATETIME alanı alır ve varsayılan tarih formatı bilgilerinizle onu yeniden biçimlendirir.İlk seçenek  zamangösterimi(timestamp)\'ne eklenecek bir offset(saat olarak)\'tir.(Varsayılan: 0).İkinci seçenek PHP\'nin strftime() fonksiyonu için uygun olan parametrelere göre farklı bir  zamangösterimi(timestamp)\'dir.';
$strTransformation_text_plain__external = 'Dış bir uygulama çalıştırır ve alanverisini standart giriş yoluyla besler.Uygulamanın standart çıktısı döner.Varsayılan hoş bir HTML çıktısı veren Tidy(Düzenli)\'dir..Güvenlik nedeniyle libraries/transformations/text_plain__external.inc.php dosyasını elle düzenlemeniz ve çalışmasına izin vereceğiniz araçları eklemeniz gerekir.İlk seçenek;çalıştırmak istediğiniz program sayısı,ikinci seçenek ise program için gerekli olan parametrelerdir.Üçüncü parametre ,eğer 1\'e setlenmişse htmlspecialchars() fonksiyonunu kullanarak çıktıyı dönüştürecektir(Varsayılan: 1).Dördüncü bir parametre ise ,eğer 1\'e setlenmişse NOWRAP(kaydırma yok) kodu tüm hücreye eklenecek ve bütün çıktı yeniden düzenlenmeden görünecektir.(Varsayılan :1)';
$strTransformation_text_plain__formatted = 'Alanın orijinal biçimlendirmesini korur.Escaping(kaçış) yapılmaz..';
$strTransformation_text_plain__imagelink = 'Bir resim ve bir link gösterir,alan dosya ismini içerir;ilk seçenek "http://domain.com/" gibi bir yazım,ikinci seçenek pixel olarak genişlik,üçüncüsü ise yüksekliktir.';
$strTransformation_text_plain__link = 'Bir link ve dosya ismini içeren alanı gösterir;ilk seçenek "http://domain.com/" gibi bir gösterim,ikincisi ise link için bir başlıktır.';
$strTransformation_text_plain__substr = 'Bir karakter dizisinin bir kısmını gösterir. İlk seçenek dizinin başlangıcından ne kadar uzağa gideceğidir (Varsayılan 0). İkinci seçenek kaç karakter alınacağıdır (Varsayılan: dizinin sonuna kadar). Üçüncü seçenek ise dizide kesilme olacaksa eklenecek ya da çıkartılacak diziyi belirtir (Varsayılan: "...").';
$strTransformation_text_plain__substr = 'Sadece yazının bir kısmını gösterir. İlk seçenek metin çıktınızın nerede olduğunu tanımlamak için kullanılacak bir offset\'tir. (varsayılan: 0).İkinci seçenek ne kadar metinin geri döndürüldüğünü belirten bir offset\'tir.. Eğer boşsa, bütün kalan metin geri döndürülür.Üçüncü seçenek bir substring döndürüldüğünde hangi karakterlerin çıktının sonuna ekleneceğini tanımlar(Varsayılan:...) .';
$strTruncateQueries = 'Görülen sorguları kısalt';
$strTurkish = 'Türkçe';
$strType = 'Tip';

$strUkrainian = 'Ukraynaca';
$strUncheckAll = 'Hiçbirisini Seçme';
$strUnicode = 'Unicode';
$strUnique = 'Unique';
$strUnknown = 'bilinmeyen';
$strUnselectAll = 'Hiçbirisini seçme';
$strUpdatePrivMessage = '%s için olan yetkileri güncellediniz.';
$strUpdateProfileMessage = 'Profil güncellendi.';
$strUpdateQuery = 'Sorguyu güncelle';
$strUpdComTab = 'Sütun_Yorumları tablosunun nasıl güncellendiğini öğrenmek istiyorsanız Dökümanlara bakınız.';
$strUpgrade = '%s %s veya daha sonraki bir sürüme yükseltme yapmanız gereklidir.';
$strUsage = 'Kullanım';
$strUseBackquotes = 'Tablo ve alan isimleri için ters tırnak " ` " işaretini kullan';
$strUseHostTable = 'Host tablosunu kullan';
$strUserAlreadyExists = '%s kullanıcısı zaten mevcut!';
$strUserEmpty = 'Kullanıcı ismi alanı doldurulmadı!';
$strUser = 'Kullanıcı';
$strUserName = 'Kullanıcı ismi';
$strUserNotFound = 'Seçili kullanıcı yetki tablosunda bulunamadı.';
$strUserOverview = 'Kullanıcı gözlem';
$strUsersDeleted = 'Seçili kullanıcılar başarıyla silindi.';
$strUsersHavingAccessToDb = '&quot;%s&quot; veritabanına erişimi olan kullanıcılar';
$strUseTabKey = 'Değerden değere geçmek için TAB tuşunu istediğiniz herhangi bir yere gitmek için CTRL+OK TUŞLARI\`nı kullanın.';
$strUseTables = 'Tabloları kullan';
$strUseTextField = 'Metin alanını kullan';
$strUseThisValue = 'Bu değeri kullan';

$strValidateSQL = 'SQL\'i doğrula';
$strValidatorError = 'SQL onaylayıcısı başlatılamadı.%sdökümanlar%s\'da belirtildiği gibi,gerekli php uzantılarının yüklenip yüklenilmediğini kontrol ediniz.';
$strValue = 'Değer';
$strVar = 'Değişken';
$strVersionInformation = 'Sürüm bilgisi'; 
$strViewDumpDatabases = 'Veritabanları döküm şeması';
$strViewDumpDB = 'Veritabanı döküm şeması';
$strViewDump = 'Tablo döküm şeması';
$strView = 'Görüntü';   
$strViewHasBeenDropped = '%s görüntüsü kaldırıldı';   

$strWebServerUploadDirectoryError = 'Yükleme  için belirttiğiniz dizine ulaşılamıyor.';
$strWebServerUploadDirectory = 'web sunucu yükleme dizini';
$strWelcome = '%s sürümüne HOŞGELDİNİZ....';
$strWestEuropean = 'Batı Avrupa';
$strWildcard = 'joker';
$strWindowNotFound = 'Tarayı penceresi güncellenemiyor...Bağlantısı olan pencereyi kapattınız veya tarayıcınızın güvenlik ayarları buna izin vermiyor';
$strWithChecked = 'Seçilileri:';
$strWritingCommentNotPossible = 'Yorum yazılması mümkün değil.';
$strWritingRelationNotPossible = 'İlişki yazılması mümkün değil.';
$strWrongUser = 'Hatalı kullanıcı adı/parola. Erişim engellendi.';

$strXML = 'XML';

$strYes = 'Evet';

$strZeroRemovesTheLimit = 'Not: Bu seçeneklerin 0\'a ayarlanması sınırı kaldırır..';
$strZip = '"ziplenmiş"';

?>
